{% extends widget.parent.theme.template %}

{% load feincms_tags i18n %}

<!-- contains hAtom microformats proposed by http://www.readability.com/publishers/guidelines/ -->
{% block body_main %}
<article class="hentry">
    <header>
        <h1 class="entry-title">{{ entry }}</h1>
        <span class="small byline">
            {% for category in entry.categories.all %}
                <a href="{{ category.get_absolute_url }}">{{ category }}</a>{% if not forloop.last %},{% else %} | {% endif %}
            {% endfor %}
            {% if entry.author.get_full_name %}
            <span class="author source-org vcard">
                {% trans 'by' %} <span class="fn">{{ entry.author.get_full_name }}</span> |
            </span>
            {% endif %}
            <time datetime="{{ entry.published_on|date:'c' }}" pubdate>{{ entry.published_on|date:"SHORT_DATE_FORMAT" }}</time>
            <time class="updated" datetime="{{ entry.last_changed|date:'c' }}"></time>
        </span>
    </header>
    <div class="entry-content">
        {% feincms_render_region entry "main" request %}
    </div>
</article>
{% endblock body_main %}
