{% extends widget.get_base_template %}

{% load i18n feincms_tags%}

{% block content %}
{% with widget.news_count as count %}
{% for object in widget.get_last_news %}
<div class="span-{% if count == 1 %}24{% endif %}{% if count == 2 %}12{% endif %}{% if count == 3 %}8{% endif %}{% if count == 4 %}6{% endif %}">
	<div class="news-item">
		<div class="news-text">
			<h3><a href="{{ object.get_absolute_url }}">{{ object.title }}</a></h3>
			{% feincms_render_region object "preview" request %}
		</div>
		<p class="a-right"><a href="{{ object.get_absolute_url }}" class="button button_secondary"><span><span>{% trans "More" %}</span></span></a></p>
	</div>
</div>
{% endfor %}
{% endwith %}
{% endblock %}
